/// <reference types="node" />
import * as opentype from 'opentype.js';
export declare type FontType = 'Standard' | 'Type1' | 'TrueType';
export declare class Font {
    type: FontType;
    name: string;
    fontMetrics: FontMetrics;
    glyphMetrics: GlyphMetrics[];
    characterWidths: CharWidthMap;
    buffer: Buffer;
    protected openTypeBuffer?: opentype.Font;
    protected fontFileArrayBuffer?: ArrayBuffer;
    static createCustomFont(filename: string, familyName: string): Font;
    /**
     * Create a Font object
     *
     * @param {string}   name     [description]
     * @param {AFMData}  afmData  [description]
     * @param {CMAPData} cmapData [description]
     */
    constructor(name: string, afmData: AFMData, cmapData?: CMAPData);
    /**
     * Get the width that a string of text would have if drawn at a specific size
     * @param {string} text [description]
     */
    getTextWidth(text: string, size: number): number;
    getEmbeddableFontBuffer(): ArrayBuffer;
    readonly unitsPerEm: number;
    readonly scale: number;
    charCodeToGlyph(charCode: number): opentype.Glyph;
    charCodeToGlyphIndex(charCode: number): number;
    getGlyphAdvanceWidth(charCode: number): number;
    getScaledGlyphAdvanceWidth(charCode: number): number;
    encodeText(s: string): string;
}
export interface FontVariant {
    bold?: boolean;
    italic?: boolean;
}
export declare type StandardFontFamilyName = 'Helvetica' | 'Courier';
export declare function isStandardFontFamilyName(name: string): boolean;
export declare class StandardFont extends Font {
    /**
     * Create a StandardFont object
     *
     * @param {string}   name     [description]
     * @param {AFMData}  afmData  [description]
     * @param {CMAPData} cmapData [description]
     */
    constructor(familyName: StandardFontFamilyName, variant?: FontVariant);
    encodeText(s: string): string;
}
export declare class CustomFont extends Font {
    type: 'TrueType';
    /**
     * Create a CustomFont object
     *
     * @param {string}   name     [description]
     * @param {AFMData}  afmData  [description]
     * @param {CMAPData} cmapData [description]
     */
    constructor(familyName: string, fontFileData: ArrayBuffer, variant?: FontVariant);
}
export interface GlyphMetrics {
    charCode: number;
    width: number;
    name: string;
}
export interface FontMetrics {
    ascender: number;
    descender: number;
    flags?: number;
    capHeight?: number;
    italicAngle?: number;
    fontBBox?: number[];
    gap?: number;
    lineHeight?: number;
    missingWidth?: number;
    stemV?: number;
    unitsPerEm?: number;
}
export declare class AFMData {
    type: FontType;
    fontMetrics: FontMetrics;
    glyphMetrics: GlyphMetrics[];
    postScriptName?: string;
}
export declare class CMAPRecord {
    unicodeCodePoint: string;
    encodingCodePoint: string;
    unicodeName: string;
    postscriptCharName: string;
}
export interface CMAPData {
    cmap: CMAPRecord[];
}
export interface CharWidthMap {
    [char: string]: number;
}
export interface ParsedFontData {
    afmData: AFMData;
    openTypeBuffer: opentype.Font;
}
