import * as opentype from 'opentype.js';
import { GlyphMetrics, ParsedFontData } from '../font';
/**
 * Open a custom TrueType or OpenType font in the file system
 * and returns it parsed out into a data stucture
 *
 * This will need to be modified for the browser as fs is a node specific API
 *
 * @param  {string}         fileName The TrueType or OpenType font in the file system to open
 * @return {ParsedFontData}          all the font data we need parsed out into a data structure
 */
export declare function openCustomFont(fileName: string): ParsedFontData;
/**
 * Parse the file data for a TrueType or OpenType font
 * and return it parsed out into a data stucture
 *
 * @param  {ArrayBuffer}         fontFileData The file data for the font file as an ArrayBuffer
 * @return {ParsedFontData}                   all the font data we need parsed out into a data structure
 */
export declare function parseCustomFont(fontFileData: ArrayBuffer): ParsedFontData;
export declare function minifyFont(bigFont: opentype.Font, scale: number): {
    font: opentype.Font;
    glyphMetrics: GlyphMetrics[];
};
